# perigon-sdk
The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://docs.perigon.io/discuss](https://docs.perigon.io/discuss)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import perigon_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import perigon_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import perigon_sdk
from perigon_sdk import ApiException
from pprint import pprint


# Initialize the API client with your API key
client = perigon_sdk.ApiClient(api_key="YOUR_API_KEY")

# Create an instance of the API class
api_instance = perigon_sdk.V1Api(client)
id = 'id_example' # str | 

# Synchronous API call
try:
    # Journalists ID
    api_response = api_instance.get_journalist_by_id(id)
    print("The response of V1Api->get_journalist_by_id:\n")
    pprint(api_response)
except ApiException as e:
    print("Exception when calling V1Api->get_journalist_by_id: %s\n" % e)

# Asynchronous API call
import asyncio

async def call_api_async():
    try:
        api_response = await api_instance.get_journalist_by_id_async(id)
        print("The async response of V1Api->get_journalist_by_id_async:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling V1Api->get_journalist_by_id_async: %s\n" % e)

# Run the async function
asyncio.run(call_api_async())

```

